/*
 * DiskSpeed
 *  
 * $Id: appclass.c,v 1.3 2017/11/11 09:59:51 bigfoot Exp $
 */

#include <libraries/gadtools.h>
#include <libraries/mui.h>
#include <mui/Aboutbox_mcc.h>

#include <proto/alib.h>
#include <proto/intuition.h>
#include <proto/locale.h>
#include <proto/muimaster.h>

#include "DiskSpeed.h"

#include "mui.h"
#include "muimacros.h"

struct Data
{
	APTR aboutwin;
};

enum
{
	MNA_ABOUT = 100,
	MNA_QUIT,
	MNA_PREFS_APP,
	MNA_PREFS_MUI,
};

#define LM(type,id,item) { type    , id##_STR   , 0, 0, id, (APTR)item }
#define BM()             { NM_ITEM , NM_BARLABEL, 0, 0,  0, NULL }
#define EM()             { NM_END  , NULL       , 0, 0,  0, NULL }

static struct NewMenu mainmenu[] =
{
	LM(NM_TITLE, WORD_MENU_Project    , 0),
	LM(NM_ITEM , WORD_MENU_About      , MNA_ABOUT),
	BM(),
	LM(NM_ITEM , WORD_MENU_Quit       , MNA_QUIT),
	LM(NM_TITLE, WORD_MENU_Settings   , 0),
	LM(NM_ITEM , WORD_MENU_SettingsApp, MNA_PREFS_APP),
	LM(NM_ITEM , WORD_MENU_SettingsMUI, MNA_PREFS_MUI),
	EM()
};

/**********************************************************************
	LocalizeMenu
**********************************************************************/

STATIC VOID LocalizeMenu(struct NewMenu *menu)
{
	while (menu->nm_Type != NM_END)
	{
		if (menu->nm_Label != NM_BARLABEL && menu->nm_Label)
		{
			menu->nm_Label = (STRPTR)GetCatalogStr(MyCatalog, menu->nm_MutualExclude, menu->nm_Label);
			menu->nm_MutualExclude = 0;
		}

		menu++;
	}
}

DEFNEW
{
	LocalizeMenu(mainmenu);

	obj = DoSuperNew(cl, obj,
		MUIA_Application_Menustrip, MUI_MakeObject(MUIO_MenustripNM, mainmenu, MUIO_MenustripNM_CommandKeyCheck),
		MUIA_Application_UsedClasses, NULL,
		TAG_MORE, msg->ops_AttrList);

	if (obj)
	{
		DoMethod(obj, MUIM_Notify, MUIA_Application_MenuAction, MUIV_EveryTime, obj, 2, MM_Application_MenuAction, MUIV_TriggerValue);
	}

	return (IPTR)obj;
}

DEFSMETHOD(Application_SaveConfig)
{
	if (msg->SaveAll)
		DoMethod(obj, MUIM_Application_Save, MUIV_Application_Save_ENVARC);

	DoMethod(obj, MUIM_Application_Save, MUIV_Application_Save_ENV);

	return set(msg->ConfigWin, MUIA_Window_Open, FALSE);
}

DEFSMETHOD(Application_MenuAction)
{
	GETDATA;

	switch (msg->MenuID)
	{
		case MNA_ABOUT:
			if (!data->aboutwin)
			{
				static const TEXT credits[] =
				{
					"\33b%p\33n\n"
					"\tNic Andrews"
					"\n\n"
					"\33b%P\33n\n"
					"\tIlkka Lehtoranta"
					"\n\n"
					"\33b%I\33n\n"
					"\tAndr Siegel"
				};

				data->aboutwin = AboutboxObject, MUIA_Aboutbox_Credits, credits, End;

				if (data->aboutwin)
					DoMethod(obj, OM_ADDMEMBER, data->aboutwin);
			}

			if (data->aboutwin)
				set(data->aboutwin, MUIA_Window_Open, TRUE);
			break;

		case MNA_QUIT:
			DoMethod(obj, MUIM_Application_PushMethod, obj, 2, MUIM_Application_ReturnID, MUIV_Application_ReturnID_Quit);
			break;

		case MNA_PREFS_APP:
			OpenAppConfigWindow();
			break;

		case MNA_PREFS_MUI:
			DoMethod(obj, MUIM_Application_OpenConfigWindow, 0, NULL);
			break;
	}

	return 0;
}

BEGINMTABLE
DECNEW
DECSMETHOD(Application_MenuAction)
DECSMETHOD(Application_SaveConfig)
ENDMTABLE

DECSUBCLASS_NC(MUIC_Application, appclass)
